@@ -6,7 +6,6 @@ from dateutil.parser import isoparse
 
 from ..models.uuid import Uuid
 from ..models.method import Method
-from ..models.status_code import StatusCode
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ApiCallWithPrice")
@@ -20,7 +19,7 @@ class ApiCallWithPrice:
     duration: Union[Unset, int] = UNSET
     email: Union[Unset, str] = UNSET
     endpoint: Union[Unset, str] = UNSET
-    id: Union[Unset, Uuid] = UNSET
+    id: Union[Unset, str] = UNSET
     ip_address: Union[Unset, str] = UNSET
     method: Union[Unset, Method] = UNSET
     minutes: Union[Unset, int] = UNSET
@@ -30,9 +29,9 @@ class ApiCallWithPrice:
     request_query_params: Union[Unset, str] = UNSET
     response_body: Union[Unset, str] = UNSET
     started_at: Union[Unset, datetime.datetime] = UNSET
-    status_code: Union[Unset, StatusCode] = UNSET
+    status_code: Union[Unset, int] = UNSET
     stripe_invoice_item_id: Union[Unset, str] = UNSET
-    token: Union[Unset, Uuid] = UNSET
+    token: Union[Unset, str] = UNSET
     updated_at: Union[Unset, datetime.datetime] = UNSET
     user_agent: Union[Unset, str] = UNSET
     user_id: Union[Unset, str] = UNSET
@@ -49,9 +48,7 @@ class ApiCallWithPrice:
         duration = self.duration
         email = self.email
         endpoint = self.endpoint
-        id: Union[Unset, str] = UNSET
-        if not isinstance(self.id, Unset):
-            id = self.id.value
+        id = self.id
         ip_address = self.ip_address
         method: Union[Unset, str] = UNSET
         if not isinstance(self.method, Unset):
@@ -65,13 +62,9 @@ class ApiCallWithPrice:
         started_at: Union[Unset, str] = UNSET
         if not isinstance(self.started_at, Unset):
             started_at = self.started_at.isoformat()
-        status_code: Union[Unset, str] = UNSET
-        if not isinstance(self.status_code, Unset):
-            status_code = self.status_code.value
+        status_code = self.status_code
         stripe_invoice_item_id = self.stripe_invoice_item_id
-        token: Union[Unset, str] = UNSET
-        if not isinstance(self.token, Unset):
-            token = self.token.value
+        token = self.token
         updated_at: Union[Unset, str] = UNSET
         if not isinstance(self.updated_at, Unset):
             updated_at = self.updated_at.isoformat()
@@ -149,12 +142,7 @@ class ApiCallWithPrice:
 
         endpoint = d.pop("endpoint", UNSET)
 
-        _id = d.pop("id", UNSET)
-        id: Union[Unset, Uuid]
-        if isinstance(_id, Unset):
-            id = UNSET
-        else:
-            id = Uuid(_id)
+        id = d.pop("id", UNSET)
 
         ip_address = d.pop("ip_address", UNSET)
 
@@ -184,21 +172,11 @@ class ApiCallWithPrice:
         else:
             started_at = isoparse(_started_at)
 
-        _status_code = d.pop("status_code", UNSET)
-        status_code: Union[Unset, StatusCode]
-        if isinstance(_status_code, Unset):
-            status_code = UNSET
-        else:
-            status_code = StatusCode(_status_code)
+        status_code = d.pop("status_code", UNSET)
 
         stripe_invoice_item_id = d.pop("stripe_invoice_item_id", UNSET)
 
-        _token = d.pop("token", UNSET)
-        token: Union[Unset, Uuid]
-        if isinstance(_token, Unset):
-            token = UNSET
-        else:
-            token = Uuid(_token)
+        token = d.pop("token", UNSET)
 
         _updated_at = d.pop("updated_at", UNSET)
         updated_at: Union[Unset, datetime.datetime]
